@@ -1,212 +1,232 @@
-( cd usr/lib ; rm -rf libkabc_groupwise.so.1 )
-( cd usr/lib ; ln -sf libkabc_groupwise.so.1.0.0 libkabc_groupwise.so.1 )
-( cd usr/lib ; rm -rf libkorganizer_eventviewer.so.1 )
-( cd usr/lib ; ln -sf libkorganizer_eventviewer.so.1.0.0 libkorganizer_eventviewer.so.1 )
-( cd usr/lib ; rm -rf libkcal_resourceremote.so )
-( cd usr/lib ; ln -sf libkcal_resourceremote.so.1.0.0 libkcal_resourceremote.so )
-( cd usr/lib ; rm -rf libkcal_newexchange.so )
-( cd usr/lib ; ln -sf libkcal_newexchange.so.1.0.0 libkcal_newexchange.so )
-( cd usr/lib ; rm -rf libkabinterfaces.so )
-( cd usr/lib ; ln -sf libkabinterfaces.so.1.0.0 libkabinterfaces.so )
-( cd usr/lib ; rm -rf libkorganizer_calendar.so )
-( cd usr/lib ; ln -sf libkorganizer_calendar.so.1.0.0 libkorganizer_calendar.so )
-( cd usr/lib ; rm -rf libkabc_slox.so )
-( cd usr/lib ; ln -sf libkabc_slox.so.0.0.0 libkabc_slox.so )
-( cd usr/lib ; rm -rf libkpimexchange.so )
-( cd usr/lib ; ln -sf libkpimexchange.so.1.0.0 libkpimexchange.so )
-( cd usr/lib ; rm -rf libkcal_xmlrpc.so.1 )
-( cd usr/lib ; ln -sf libkcal_xmlrpc.so.1.0.0 libkcal_xmlrpc.so.1 )
-( cd usr/lib ; rm -rf libkslox.so )
-( cd usr/lib ; ln -sf libkslox.so.0.0.0 libkslox.so )
-( cd usr/lib ; rm -rf libkabc_newexchange.so.1 )
-( cd usr/lib ; ln -sf libkabc_newexchange.so.1.0.0 libkabc_newexchange.so.1 )
-( cd usr/lib ; rm -rf libksieve.so )
-( cd usr/lib ; ln -sf libksieve.so.0.0.0 libksieve.so )
-( cd usr/lib ; rm -rf libkode.so.1 )
-( cd usr/lib ; ln -sf libkode.so.1.0.0 libkode.so.1 )
-( cd usr/lib ; rm -rf libkcal.so.2 )
-( cd usr/lib ; ln -sf libkcal.so.2.0.0 libkcal.so.2 )
-( cd usr/lib ; rm -rf libkaddressbook.so )
-( cd usr/lib ; ln -sf libkaddressbook.so.0.0.0 libkaddressbook.so )
 ( cd usr/lib ; rm -rf libkpilot.so.0 )
 ( cd usr/lib ; ln -sf libkpilot.so.0.0.0 libkpilot.so.0 )
-( cd usr/lib ; rm -rf libknoteskolab.so )
-( cd usr/lib ; ln -sf libknoteskolab.so.0.0.0 libknoteskolab.so )
-( cd usr/lib ; rm -rf libkabc_newexchange.so )
-( cd usr/lib ; ln -sf libkabc_newexchange.so.1.0.0 libkabc_newexchange.so )
-( cd usr/lib ; rm -rf libkleopatra.so )
-( cd usr/lib ; ln -sf libkleopatra.so.1.0.0 libkleopatra.so )
-( cd usr/lib ; rm -rf libkontact.so )
-( cd usr/lib ; ln -sf libkontact.so.1.0.0 libkontact.so )
-( cd usr/lib ; rm -rf libindex.so )
-( cd usr/lib ; ln -sf libindex.so.0.0.0 libindex.so )
-( cd usr/lib ; rm -rf libkholidays.so.1 )
-( cd usr/lib ; ln -sf libkholidays.so.1.0.0 libkholidays.so.1 )
-( cd usr/lib ; rm -rf libknotes_xmlrpc.so.1 )
-( cd usr/lib ; ln -sf libknotes_xmlrpc.so.1.0.0 libknotes_xmlrpc.so.1 )
-( cd usr/lib ; rm -rf libkgroupwaredav.so.0 )
-( cd usr/lib ; ln -sf libkgroupwaredav.so.0.0.0 libkgroupwaredav.so.0 )
-( cd usr/lib ; rm -rf libkabc_slox.so.0 )
-( cd usr/lib ; ln -sf libkabc_slox.so.0.0.0 libkabc_slox.so.0 )
-( cd usr/lib ; rm -rf libkdepim.so )
-( cd usr/lib ; ln -sf libkdepim.so.1.0.0 libkdepim.so )
-( cd usr/lib ; rm -rf libkcal.so )
-( cd usr/lib ; ln -sf libkcal.so.2.0.0 libkcal.so )
-( cd usr/lib ; rm -rf libkcal_groupwise.so )
-( cd usr/lib ; ln -sf libkcal_groupwise.so.1.0.0 libkcal_groupwise.so )
-( cd usr/lib ; rm -rf libqgpgme.so.0 )
-( cd usr/lib ; ln -sf libqgpgme.so.0.0.0 libqgpgme.so.0 )
-( cd usr/lib ; rm -rf libkorganizer.so.1 )
-( cd usr/lib ; ln -sf libkorganizer.so.1.0.0 libkorganizer.so.1 )
-( cd usr/lib ; rm -rf libkpgp.so )
-( cd usr/lib ; ln -sf libkpgp.so.2.2.0 libkpgp.so )
-( cd usr/lib ; rm -rf libkdepim.so.1 )
-( cd usr/lib ; ln -sf libkdepim.so.1.0.0 libkdepim.so.1 )
-( cd usr/lib ; rm -rf libkcal_newexchange.so.1 )
-( cd usr/lib ; ln -sf libkcal_newexchange.so.1.0.0 libkcal_newexchange.so.1 )
-( cd usr/lib ; rm -rf libkorganizer_calendar.so.1 )
-( cd usr/lib ; ln -sf libkorganizer_calendar.so.1.0.0 libkorganizer_calendar.so.1 )
-( cd usr/lib ; rm -rf libkgantt.so )
-( cd usr/lib ; ln -sf libkgantt.so.0.0.2 libkgantt.so )
-( cd usr/lib ; rm -rf libkabckolab.so.0 )
-( cd usr/lib ; ln -sf libkabckolab.so.0.0.0 libkabckolab.so.0 )
-( cd usr/lib ; rm -rf libkaddressbook.so.0 )
-( cd usr/lib ; ln -sf libkaddressbook.so.0.0.0 libkaddressbook.so.0 )
-( cd usr/lib ; rm -rf libknoteskolab.so.0 )
-( cd usr/lib ; ln -sf libknoteskolab.so.0.0.0 libknoteskolab.so.0 )
-( cd usr/lib ; rm -rf libkocorehelper.so )
-( cd usr/lib ; ln -sf libkocorehelper.so.1.0.0 libkocorehelper.so )
-( cd usr/lib ; rm -rf libkorg_stdprinting.so )
-( cd usr/lib ; ln -sf libkorg_stdprinting.so.1.0.0 libkorg_stdprinting.so )
-( cd usr/lib ; rm -rf libkabc_groupwise.so )
-( cd usr/lib ; ln -sf libkabc_groupwise.so.1.0.0 libkabc_groupwise.so )
-( cd usr/lib ; rm -rf libktnef.so.1 )
-( cd usr/lib ; ln -sf libktnef.so.1.0.0 libktnef.so.1 )
-( cd usr/lib ; rm -rf libksieve.so.0 )
-( cd usr/lib ; ln -sf libksieve.so.0.0.0 libksieve.so.0 )
-( cd usr/lib ; rm -rf libkcal_slox.so )
-( cd usr/lib ; ln -sf libkcal_slox.so.0.0.0 libkcal_slox.so )
-( cd usr/lib ; rm -rf libkpgp.so.2 )
-( cd usr/lib ; ln -sf libkpgp.so.2.2.0 libkpgp.so.2 )
-( cd usr/lib ; rm -rf libkmime.so.2 )
-( cd usr/lib ; ln -sf libkmime.so.2.2.0 libkmime.so.2 )
-( cd usr/lib ; rm -rf libkpilot.so )
-( cd usr/lib ; ln -sf libkpilot.so.0.0.0 libkpilot.so )
-( cd usr/lib ; rm -rf libkmime.so )
-( cd usr/lib ; ln -sf libkmime.so.2.2.0 libkmime.so )
-( cd usr/lib ; rm -rf libkleopatra.so.1 )
-( cd usr/lib ; ln -sf libkleopatra.so.1.0.0 libkleopatra.so.1 )
-( cd usr/lib ; rm -rf libkabckolab.so )
-( cd usr/lib ; ln -sf libkabckolab.so.0.0.0 libkabckolab.so )
-( cd usr/lib ; rm -rf libkpimexchange.so.1 )
-( cd usr/lib ; ln -sf libkpimexchange.so.1.0.0 libkpimexchange.so.1 )
-( cd usr/lib ; rm -rf libkcal_slox.so.0 )
-( cd usr/lib ; ln -sf libkcal_slox.so.0.0.0 libkcal_slox.so.0 )
-( cd usr/lib ; rm -rf libkabc_groupdav.so )
-( cd usr/lib ; ln -sf libkabc_groupdav.so.1.0.0 libkabc_groupdav.so )
-( cd usr/lib ; rm -rf libkcal_groupdav.so.1 )
-( cd usr/lib ; ln -sf libkcal_groupdav.so.1.0.0 libkcal_groupdav.so.1 )
-( cd usr/lib ; rm -rf libkorganizer_eventviewer.so )
-( cd usr/lib ; ln -sf libkorganizer_eventviewer.so.1.0.0 libkorganizer_eventviewer.so )
-( cd usr/lib ; rm -rf libkcal_resourcefeatureplan.so.1 )
-( cd usr/lib ; ln -sf libkcal_resourcefeatureplan.so.1.0.0 libkcal_resourcefeatureplan.so.1 )
-( cd usr/lib ; rm -rf libgpgme++.so )
-( cd usr/lib ; ln -sf libgpgme++.so.0.2.0 libgpgme++.so )
-( cd usr/lib ; rm -rf libkcal_resourceremote.so.1 )
-( cd usr/lib ; ln -sf libkcal_resourceremote.so.1.0.0 libkcal_resourceremote.so.1 )
-( cd usr/lib ; rm -rf libknotes_xmlrpc.so )
-( cd usr/lib ; ln -sf libknotes_xmlrpc.so.1.0.0 libknotes_xmlrpc.so )
-( cd usr/lib ; rm -rf libqgpgme.so )
-( cd usr/lib ; ln -sf libqgpgme.so.0.0.0 libqgpgme.so )
-( cd usr/lib ; rm -rf libkpinterfaces.so )
-( cd usr/lib ; ln -sf libkpinterfaces.so.1.0.0 libkpinterfaces.so )
-( cd usr/lib ; rm -rf libmimelib.so.1 )
-( cd usr/lib ; ln -sf libmimelib.so.1.0.1 libmimelib.so.1 )
-( cd usr/lib ; rm -rf libkocorehelper.so.1 )
-( cd usr/lib ; ln -sf libkocorehelper.so.1.0.0 libkocorehelper.so.1 )
-( cd usr/lib ; rm -rf libkgroupwarebase.so.0 )
-( cd usr/lib ; ln -sf libkgroupwarebase.so.0.0.0 libkgroupwarebase.so.0 )
-( cd usr/lib ; rm -rf libmimelib.so )
-( cd usr/lib ; ln -sf libmimelib.so.1.0.1 libmimelib.so )
-( cd usr/lib ; rm -rf libkabinterfaces.so.1 )
-( cd usr/lib ; ln -sf libkabinterfaces.so.1.0.0 libkabinterfaces.so.1 )
-( cd usr/lib ; rm -rf libkgroupwarebase.so )
-( cd usr/lib ; ln -sf libkgroupwarebase.so.0.0.0 libkgroupwarebase.so )
-( cd usr/lib ; rm -rf libkcal_groupwise.so.1 )
-( cd usr/lib ; ln -sf libkcal_groupwise.so.1.0.0 libkcal_groupwise.so.1 )
-( cd usr/lib ; rm -rf libgpgme++.so.0 )
-( cd usr/lib ; ln -sf libgpgme++.so.0.2.0 libgpgme++.so.0 )
-( cd usr/lib ; rm -rf libkabc_xmlrpc.so.1 )
-( cd usr/lib ; ln -sf libkabc_xmlrpc.so.1.0.0 libkabc_xmlrpc.so.1 )
-( cd usr/lib ; rm -rf libkcalkolab.so.0 )
-( cd usr/lib ; ln -sf libkcalkolab.so.0.0.0 libkcalkolab.so.0 )
-( cd usr/lib ; rm -rf libkpimidentities.so.1 )
-( cd usr/lib ; ln -sf libkpimidentities.so.1.0.0 libkpimidentities.so.1 )
-( cd usr/lib ; rm -rf libkabc_groupdav.so.1 )
-( cd usr/lib ; ln -sf libkabc_groupdav.so.1.0.0 libkabc_groupdav.so.1 )
-( cd usr/lib ; rm -rf libktnef.so )
-( cd usr/lib ; ln -sf libktnef.so.1.0.0 libktnef.so )
-( cd usr/lib ; rm -rf libkholidays.so )
-( cd usr/lib ; ln -sf libkholidays.so.1.0.0 libkholidays.so )
-( cd usr/lib ; rm -rf libkcal_resourcefeatureplan.so )
-( cd usr/lib ; ln -sf libkcal_resourcefeatureplan.so.1.0.0 libkcal_resourcefeatureplan.so )
-( cd usr/lib ; rm -rf libkcal_xmlrpc.so )
-( cd usr/lib ; ln -sf libkcal_xmlrpc.so.1.0.0 libkcal_xmlrpc.so )
-( cd usr/lib ; rm -rf libindex.so.0 )
-( cd usr/lib ; ln -sf libindex.so.0.0.0 libindex.so.0 )
-( cd usr/lib ; rm -rf libkode.so )
-( cd usr/lib ; ln -sf libkode.so.1.0.0 libkode.so )
-( cd usr/lib ; rm -rf libkpinterfaces.so.1 )
-( cd usr/lib ; ln -sf libkpinterfaces.so.1.0.0 libkpinterfaces.so.1 )
-( cd usr/lib ; rm -rf libkgroupwaredav.so )
-( cd usr/lib ; ln -sf libkgroupwaredav.so.0.0.0 libkgroupwaredav.so )
-( cd usr/lib ; rm -rf libkorg_stdprinting.so.1 )
-( cd usr/lib ; ln -sf libkorg_stdprinting.so.1.0.0 libkorg_stdprinting.so.1 )
-( cd usr/lib ; rm -rf libkslox.so.0 )
-( cd usr/lib ; ln -sf libkslox.so.0.0.0 libkslox.so.0 )
 ( cd usr/lib ; rm -rf libkcal_groupdav.so )
 ( cd usr/lib ; ln -sf libkcal_groupdav.so.1.0.0 libkcal_groupdav.so )
-( cd usr/lib ; rm -rf libkcalkolab.so )
-( cd usr/lib ; ln -sf libkcalkolab.so.0.0.0 libkcalkolab.so )
-( cd usr/lib ; rm -rf libkontact.so.1 )
-( cd usr/lib ; ln -sf libkontact.so.1.0.0 libkontact.so.1 )
+( cd usr/lib ; rm -rf libkslox.so.0 )
+( cd usr/lib ; ln -sf libkslox.so.0.0.0 libkslox.so.0 )
+( cd usr/lib ; rm -rf libqgpgme.so )
+( cd usr/lib ; ln -sf libqgpgme.so.0.0.0 libqgpgme.so )
+( cd usr/lib ; rm -rf libkmime.so )
+( cd usr/lib ; ln -sf libkmime.so.2.2.0 libkmime.so )
+( cd usr/lib ; rm -rf libgpgme++.so.0 )
+( cd usr/lib ; ln -sf libgpgme++.so.0.3.0 libgpgme++.so.0 )
 ( cd usr/lib ; rm -rf libkorganizer.so )
 ( cd usr/lib ; ln -sf libkorganizer.so.1.0.0 libkorganizer.so )
-( cd usr/lib ; rm -rf libkpimidentities.so )
-( cd usr/lib ; ln -sf libkpimidentities.so.1.0.0 libkpimidentities.so )
+( cd usr/lib ; rm -rf libkslox.so )
+( cd usr/lib ; ln -sf libkslox.so.0.0.0 libkslox.so )
+( cd usr/lib ; rm -rf libmimelib.so )
+( cd usr/lib ; ln -sf libmimelib.so.1.0.1 libmimelib.so )
+( cd usr/lib ; rm -rf libkdepim.so.1 )
+( cd usr/lib ; ln -sf libkdepim.so.1.0.0 libkdepim.so.1 )
+( cd usr/lib ; rm -rf libkgantt.so )
+( cd usr/lib ; ln -sf libkgantt.so.0.0.2 libkgantt.so )
+( cd usr/lib ; rm -rf libkpilot.so )
+( cd usr/lib ; ln -sf libkpilot.so.0.0.0 libkpilot.so )
+( cd usr/lib ; rm -rf libqgpgme.so.0 )
+( cd usr/lib ; ln -sf libqgpgme.so.0.0.0 libqgpgme.so.0 )
+( cd usr/lib ; rm -rf libkabinterfaces.so.1 )
+( cd usr/lib ; ln -sf libkabinterfaces.so.1.0.0 libkabinterfaces.so.1 )
+( cd usr/lib ; rm -rf libindex.so.0 )
+( cd usr/lib ; ln -sf libindex.so.0.0.0 libindex.so.0 )
+( cd usr/lib ; rm -rf libkorganizer.so.1 )
+( cd usr/lib ; ln -sf libkorganizer.so.1.0.0 libkorganizer.so.1 )
+( cd usr/lib ; rm -rf libkgroupwaredav.so )
+( cd usr/lib ; ln -sf libkgroupwaredav.so.0.0.0 libkgroupwaredav.so )
+( cd usr/lib ; rm -rf libkabc_slox.so.0 )
+( cd usr/lib ; ln -sf libkabc_slox.so.0.0.0 libkabc_slox.so.0 )
+( cd usr/lib ; rm -rf libkpinterfaces.so.1 )
+( cd usr/lib ; ln -sf libkpinterfaces.so.1.0.0 libkpinterfaces.so.1 )
+( cd usr/lib ; rm -rf libkcal_resourcefeatureplan.so )
+( cd usr/lib ; ln -sf libkcal_resourcefeatureplan.so.1.0.0 libkcal_resourcefeatureplan.so )
+( cd usr/lib ; rm -rf libkcalscalix.so )
+( cd usr/lib ; ln -sf libkcalscalix.so.0.0.0 libkcalscalix.so )
+( cd usr/lib ; rm -rf libkorg_stdprinting.so.1 )
+( cd usr/lib ; ln -sf libkorg_stdprinting.so.1.0.0 libkorg_stdprinting.so.1 )
+( cd usr/lib ; rm -rf libkorg_stdprinting.so )
+( cd usr/lib ; ln -sf libkorg_stdprinting.so.1.0.0 libkorg_stdprinting.so )
+( cd usr/lib ; rm -rf libkabcscalix.so )
+( cd usr/lib ; ln -sf libkabcscalix.so.0.0.0 libkabcscalix.so )
+( cd usr/lib ; rm -rf libknotes_xmlrpc.so.1 )
+( cd usr/lib ; ln -sf libknotes_xmlrpc.so.1.0.0 libknotes_xmlrpc.so.1 )
+( cd usr/lib ; rm -rf libgwsoap.so )
+( cd usr/lib ; ln -sf libgwsoap.so.0.0.0 libgwsoap.so )
+( cd usr/lib ; rm -rf libindex.so )
+( cd usr/lib ; ln -sf libindex.so.0.0.0 libindex.so )
+( cd usr/lib ; rm -rf libkcalscalix.so.0 )
+( cd usr/lib ; ln -sf libkcalscalix.so.0.0.0 libkcalscalix.so.0 )
+( cd usr/lib ; rm -rf libkabc_xmlrpc.so.1 )
+( cd usr/lib ; ln -sf libkabc_xmlrpc.so.1.0.0 libkabc_xmlrpc.so.1 )
+( cd usr/lib ; rm -rf libgwsoap.so.0 )
+( cd usr/lib ; ln -sf libgwsoap.so.0.0.0 libgwsoap.so.0 )
+( cd usr/lib ; rm -rf libkpgp.so )
+( cd usr/lib ; ln -sf libkpgp.so.2.2.0 libkpgp.so )
+( cd usr/lib ; rm -rf libknotesscalix.so )
+( cd usr/lib ; ln -sf libknotesscalix.so.0.0.0 libknotesscalix.so )
+( cd usr/lib ; rm -rf libkontact.so )
+( cd usr/lib ; ln -sf libkontact.so.1.0.0 libkontact.so )
+( cd usr/lib ; rm -rf libknotes_xmlrpc.so )
+( cd usr/lib ; ln -sf libknotes_xmlrpc.so.1.0.0 libknotes_xmlrpc.so )
+( cd usr/lib ; rm -rf libknoteskolab.so.0 )
+( cd usr/lib ; ln -sf libknoteskolab.so.0.0.0 libknoteskolab.so.0 )
+( cd usr/lib ; rm -rf libkcal_resourceremote.so.1 )
+( cd usr/lib ; ln -sf libkcal_resourceremote.so.1.0.0 libkcal_resourceremote.so.1 )
+( cd usr/lib ; rm -rf libkcal_resourcefeatureplan.so.1 )
+( cd usr/lib ; ln -sf libkcal_resourcefeatureplan.so.1.0.0 libkcal_resourcefeatureplan.so.1 )
+( cd usr/lib ; rm -rf libkcal_resourceremote.so )
+( cd usr/lib ; ln -sf libkcal_resourceremote.so.1.0.0 libkcal_resourceremote.so )
+( cd usr/lib ; rm -rf libkorganizer_calendar.so.1 )
+( cd usr/lib ; ln -sf libkorganizer_calendar.so.1.0.0 libkorganizer_calendar.so.1 )
+( cd usr/lib ; rm -rf libkcal_slox.so.0 )
+( cd usr/lib ; ln -sf libkcal_slox.so.0.0.0 libkcal_slox.so.0 )
+( cd usr/lib ; rm -rf libknotesscalix.so.0 )
+( cd usr/lib ; ln -sf libknotesscalix.so.0.0.0 libknotesscalix.so.0 )
+( cd usr/lib ; rm -rf libkabc_newexchange.so.1 )
+( cd usr/lib ; ln -sf libkabc_newexchange.so.1.0.0 libkabc_newexchange.so.1 )
+( cd usr/lib ; rm -rf libkode.so.1 )
+( cd usr/lib ; ln -sf libkode.so.1.0.0 libkode.so.1 )
 ( cd usr/lib ; rm -rf libkabc_xmlrpc.so )
 ( cd usr/lib ; ln -sf libkabc_xmlrpc.so.1.0.0 libkabc_xmlrpc.so )
+( cd usr/lib ; rm -rf libkontact.so.1 )
+( cd usr/lib ; ln -sf libkontact.so.1.0.0 libkontact.so.1 )
+( cd usr/lib ; rm -rf libkcal_slox.so )
+( cd usr/lib ; ln -sf libkcal_slox.so.0.0.0 libkcal_slox.so )
+( cd usr/lib ; rm -rf libkabc_groupdav.so.1 )
+( cd usr/lib ; ln -sf libkabc_groupdav.so.1.0.0 libkabc_groupdav.so.1 )
+( cd usr/lib ; rm -rf libkpgp.so.2 )
+( cd usr/lib ; ln -sf libkpgp.so.2.2.0 libkpgp.so.2 )
+( cd usr/lib ; rm -rf libkleopatra.so.1 )
+( cd usr/lib ; ln -sf libkleopatra.so.1.0.0 libkleopatra.so.1 )
+( cd usr/lib ; rm -rf libkholidays.so )
+( cd usr/lib ; ln -sf libkholidays.so.1.0.0 libkholidays.so )
+( cd usr/lib ; rm -rf libkocorehelper.so )
+( cd usr/lib ; ln -sf libkocorehelper.so.1.0.0 libkocorehelper.so )
+( cd usr/lib ; rm -rf libkcal.so )
+( cd usr/lib ; ln -sf libkcal.so.2.0.0 libkcal.so )
+( cd usr/lib ; rm -rf libknoteskolab.so )
+( cd usr/lib ; ln -sf libknoteskolab.so.0.0.0 libknoteskolab.so )
+( cd usr/lib ; rm -rf libkabckolab.so )
+( cd usr/lib ; ln -sf libkabckolab.so.0.0.0 libkabckolab.so )
+( cd usr/lib ; rm -rf libkabcscalix.so.0 )
+( cd usr/lib ; ln -sf libkabcscalix.so.0.0.0 libkabcscalix.so.0 )
+( cd usr/lib ; rm -rf libkorganizer_calendar.so )
+( cd usr/lib ; ln -sf libkorganizer_calendar.so.1.0.0 libkorganizer_calendar.so )
+( cd usr/lib ; rm -rf libkpimexchange.so.1 )
+( cd usr/lib ; ln -sf libkpimexchange.so.1.0.0 libkpimexchange.so.1 )
+( cd usr/lib ; rm -rf libkleopatra.so )
+( cd usr/lib ; ln -sf libkleopatra.so.1.0.0 libkleopatra.so )
+( cd usr/lib ; rm -rf libkcalkolab.so )
+( cd usr/lib ; ln -sf libkcalkolab.so.0.0.0 libkcalkolab.so )
+( cd usr/lib ; rm -rf libksieve.so )
+( cd usr/lib ; ln -sf libksieve.so.0.0.0 libksieve.so )
+( cd usr/lib ; rm -rf libkabckolab.so.0 )
+( cd usr/lib ; ln -sf libkabckolab.so.0.0.0 libkabckolab.so.0 )
+( cd usr/lib ; rm -rf libgpgme++.so )
+( cd usr/lib ; ln -sf libgpgme++.so.0.3.0 libgpgme++.so )
+( cd usr/lib ; rm -rf libkgroupwaredav.so.0 )
+( cd usr/lib ; ln -sf libkgroupwaredav.so.0.0.0 libkgroupwaredav.so.0 )
+( cd usr/lib ; rm -rf libktnef.so )
+( cd usr/lib ; ln -sf libktnef.so.1.0.0 libktnef.so )
+( cd usr/lib ; rm -rf libkgroupwarebase.so )
+( cd usr/lib ; ln -sf libkgroupwarebase.so.0.0.0 libkgroupwarebase.so )
+( cd usr/lib ; rm -rf libkaddressbook.so.0 )
+( cd usr/lib ; ln -sf libkaddressbook.so.0.0.0 libkaddressbook.so.0 )
+( cd usr/lib ; rm -rf libkpimidentities.so.1 )
+( cd usr/lib ; ln -sf libkpimidentities.so.1.0.0 libkpimidentities.so.1 )
+( cd usr/lib ; rm -rf libmimelib.so.1 )
+( cd usr/lib ; ln -sf libmimelib.so.1.0.1 libmimelib.so.1 )
+( cd usr/lib ; rm -rf libkcal_xmlrpc.so.1 )
+( cd usr/lib ; ln -sf libkcal_xmlrpc.so.1.0.0 libkcal_xmlrpc.so.1 )
+( cd usr/lib ; rm -rf libkpinterfaces.so )
+( cd usr/lib ; ln -sf libkpinterfaces.so.1.0.0 libkpinterfaces.so )
+( cd usr/lib ; rm -rf libkholidays.so.1 )
+( cd usr/lib ; ln -sf libkholidays.so.1.0.0 libkholidays.so.1 )
+( cd usr/lib ; rm -rf libkcal.so.2 )
+( cd usr/lib ; ln -sf libkcal.so.2.0.0 libkcal.so.2 )
+( cd usr/lib ; rm -rf libkcalkolab.so.0 )
+( cd usr/lib ; ln -sf libkcalkolab.so.0.0.0 libkcalkolab.so.0 )
+( cd usr/lib ; rm -rf libkpimidentities.so )
+( cd usr/lib ; ln -sf libkpimidentities.so.1.0.0 libkpimidentities.so )
+( cd usr/lib ; rm -rf libkdepim.so )
+( cd usr/lib ; ln -sf libkdepim.so.1.0.0 libkdepim.so )
+( cd usr/lib ; rm -rf libkcal_newexchange.so )
+( cd usr/lib ; ln -sf libkcal_newexchange.so.1.0.0 libkcal_newexchange.so )
+( cd usr/lib ; rm -rf libkgroupwarebase.so.0 )
+( cd usr/lib ; ln -sf libkgroupwarebase.so.0.0.0 libkgroupwarebase.so.0 )
+( cd usr/lib ; rm -rf libkaddressbook.so )
+( cd usr/lib ; ln -sf libkaddressbook.so.0.0.0 libkaddressbook.so )
+( cd usr/lib ; rm -rf libkcal_xmlrpc.so )
+( cd usr/lib ; ln -sf libkcal_xmlrpc.so.1.0.0 libkcal_xmlrpc.so )
+( cd usr/lib ; rm -rf libkorganizer_eventviewer.so.1 )
+( cd usr/lib ; ln -sf libkorganizer_eventviewer.so.1.0.0 libkorganizer_eventviewer.so.1 )
+( cd usr/lib ; rm -rf libkpimexchange.so )
+( cd usr/lib ; ln -sf libkpimexchange.so.1.0.0 libkpimexchange.so )
+( cd usr/lib ; rm -rf libkcal_groupdav.so.1 )
+( cd usr/lib ; ln -sf libkcal_groupdav.so.1.0.0 libkcal_groupdav.so.1 )
+( cd usr/lib ; rm -rf libkabc_newexchange.so )
+( cd usr/lib ; ln -sf libkabc_newexchange.so.1.0.0 libkabc_newexchange.so )
+( cd usr/lib ; rm -rf libksieve.so.0 )
+( cd usr/lib ; ln -sf libksieve.so.0.0.0 libksieve.so.0 )
+( cd usr/lib ; rm -rf libktnef.so.1 )
+( cd usr/lib ; ln -sf libktnef.so.1.0.0 libktnef.so.1 )
+( cd usr/lib ; rm -rf libkorganizer_eventviewer.so )
+( cd usr/lib ; ln -sf libkorganizer_eventviewer.so.1.0.0 libkorganizer_eventviewer.so )
+( cd usr/lib ; rm -rf libkcal_newexchange.so.1 )
+( cd usr/lib ; ln -sf libkcal_newexchange.so.1.0.0 libkcal_newexchange.so.1 )
+( cd usr/lib ; rm -rf libkcal_groupwise.so.1 )
+( cd usr/lib ; ln -sf libkcal_groupwise.so.1.0.0 libkcal_groupwise.so.1 )
+( cd usr/lib ; rm -rf libkabinterfaces.so )
+( cd usr/lib ; ln -sf libkabinterfaces.so.1.0.0 libkabinterfaces.so )
+( cd usr/lib ; rm -rf libkabc_groupdav.so )
+( cd usr/lib ; ln -sf libkabc_groupdav.so.1.0.0 libkabc_groupdav.so )
+( cd usr/lib ; rm -rf libkocorehelper.so.1 )
+( cd usr/lib ; ln -sf libkocorehelper.so.1.0.0 libkocorehelper.so.1 )
+( cd usr/lib ; rm -rf libkabc_groupwise.so.1 )
+( cd usr/lib ; ln -sf libkabc_groupwise.so.1.0.0 libkabc_groupwise.so.1 )
+( cd usr/lib ; rm -rf libkcal_groupwise.so )
+( cd usr/lib ; ln -sf libkcal_groupwise.so.1.0.0 libkcal_groupwise.so )
+( cd usr/lib ; rm -rf libkabc_groupwise.so )
+( cd usr/lib ; ln -sf libkabc_groupwise.so.1.0.0 libkabc_groupwise.so )
+( cd usr/lib ; rm -rf libknodecommon.so )
+( cd usr/lib ; ln -sf libknodecommon.so.3.0.0 libknodecommon.so )
+( cd usr/lib ; rm -rf libkode.so )
+( cd usr/lib ; ln -sf libkode.so.1.0.0 libkode.so )
+( cd usr/lib ; rm -rf libknodecommon.so.3 )
+( cd usr/lib ; ln -sf libknodecommon.so.3.0.0 libknodecommon.so.3 )
+( cd usr/lib ; rm -rf libkmime.so.2 )
+( cd usr/lib ; ln -sf libkmime.so.2.2.0 libkmime.so.2 )
+( cd usr/lib ; rm -rf libkabc_slox.so )
+( cd usr/lib ; ln -sf libkabc_slox.so.0.0.0 libkabc_slox.so )
 ( cd usr/lib ; rm -rf libkgantt.so.0 )
 ( cd usr/lib ; ln -sf libkgantt.so.0.0.2 libkgantt.so.0 )
-( cd usr/share/doc/HTML/en/kleopatra ; rm -rf common )
-( cd usr/share/doc/HTML/en/kleopatra ; ln -sf /usr/share/doc/HTML/en/common common )
-( cd usr/share/doc/HTML/en/karm ; rm -rf common )
-( cd usr/share/doc/HTML/en/karm ; ln -sf /usr/share/doc/HTML/en/common common )
-( cd usr/share/doc/HTML/en/kpilot ; rm -rf common )
-( cd usr/share/doc/HTML/en/kpilot ; ln -sf /usr/share/doc/HTML/en/common common )
-( cd usr/share/doc/HTML/en/kontact ; rm -rf common )
-( cd usr/share/doc/HTML/en/kontact ; ln -sf /usr/share/doc/HTML/en/common common )
-( cd usr/share/doc/HTML/en/korn ; rm -rf common )
-( cd usr/share/doc/HTML/en/korn ; ln -sf /usr/share/doc/HTML/en/common common )
-( cd usr/share/doc/HTML/en/korganizer ; rm -rf common )
-( cd usr/share/doc/HTML/en/korganizer ; ln -sf /usr/share/doc/HTML/en/common common )
 ( cd usr/share/doc/HTML/en/kalarm ; rm -rf common )
 ( cd usr/share/doc/HTML/en/kalarm ; ln -sf /usr/share/doc/HTML/en/common common )
-( cd usr/share/doc/HTML/en/knode ; rm -rf common )
-( cd usr/share/doc/HTML/en/knode ; ln -sf /usr/share/doc/HTML/en/common common )
-( cd usr/share/doc/HTML/en/kwatchgnupg ; rm -rf common )
-( cd usr/share/doc/HTML/en/kwatchgnupg ; ln -sf /usr/share/doc/HTML/en/common common )
-( cd usr/share/doc/HTML/en/kaddressbook ; rm -rf common )
-( cd usr/share/doc/HTML/en/kaddressbook ; ln -sf /usr/share/doc/HTML/en/common common )
-( cd usr/share/doc/HTML/en/ktnef ; rm -rf common )
-( cd usr/share/doc/HTML/en/ktnef ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/share/doc/HTML/en/korganizer ; rm -rf common )
+( cd usr/share/doc/HTML/en/korganizer ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/share/doc/HTML/en/karm ; rm -rf common )
+( cd usr/share/doc/HTML/en/karm ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/share/doc/HTML/en/konsolekalendar ; rm -rf common )
+( cd usr/share/doc/HTML/en/konsolekalendar ; ln -sf /usr/share/doc/HTML/en/common common )
 ( cd usr/share/doc/HTML/en/kandy ; rm -rf common )
 ( cd usr/share/doc/HTML/en/kandy ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/share/doc/HTML/en/kwatchgnupg ; rm -rf common )
+( cd usr/share/doc/HTML/en/kwatchgnupg ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/share/doc/HTML/en/knotes ; rm -rf common )
+( cd usr/share/doc/HTML/en/knotes ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/share/doc/HTML/en/korn ; rm -rf common )
+( cd usr/share/doc/HTML/en/korn ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/share/doc/HTML/en/knode ; rm -rf common )
+( cd usr/share/doc/HTML/en/knode ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/share/doc/HTML/en/kontact ; rm -rf common )
+( cd usr/share/doc/HTML/en/kontact ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/share/doc/HTML/en/kleopatra ; rm -rf common )
+( cd usr/share/doc/HTML/en/kleopatra ; ln -sf /usr/share/doc/HTML/en/common common )
 ( cd usr/share/doc/HTML/en/akregator ; rm -rf common )
 ( cd usr/share/doc/HTML/en/akregator ; ln -sf /usr/share/doc/HTML/en/common common )
 ( cd usr/share/doc/HTML/en/kmail ; rm -rf common )
 ( cd usr/share/doc/HTML/en/kmail ; ln -sf /usr/share/doc/HTML/en/common common )
-( cd usr/share/doc/HTML/en/konsolekalendar ; rm -rf common )
-( cd usr/share/doc/HTML/en/konsolekalendar ; ln -sf /usr/share/doc/HTML/en/common common )
-( cd usr/share/doc/HTML/en/knotes ; rm -rf common )
-( cd usr/share/doc/HTML/en/knotes ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/share/doc/HTML/en/kaddressbook ; rm -rf common )
+( cd usr/share/doc/HTML/en/kaddressbook ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/share/doc/HTML/en/kpilot ; rm -rf common )
+( cd usr/share/doc/HTML/en/kpilot ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/share/doc/HTML/en/ktnef ; rm -rf common )
+( cd usr/share/doc/HTML/en/ktnef ; ln -sf /usr/share/doc/HTML/en/common common )
